import type { Batch, Datastore, Key, KeyQuery, Options, Pair, Query } from 'interface-datastore';
import type { AwaitIterable } from 'interface-store';
export declare class BaseDatastore implements Datastore {
    open(): Promise<void>;
    close(): Promise<void>;
    put(key: Key, val: Uint8Array, options?: Options): Promise<void>;
    get(key: Key, options?: Options): Promise<Uint8Array>;
    has(key: Key, options?: Options): Promise<boolean>;
    delete(key: Key, options?: Options): Promise<void>;
    putMany(source: AwaitIterable<Pair>, options?: Options): AsyncIterable<Pair>;
    getMany(source: AwaitIterable<Key>, options?: Options): AsyncIterable<Uint8Array>;
    deleteMany(source: AwaitIterable<Key>, options?: Options): AsyncIterable<Key>;
    batch(): Batch;
    /**
     * Extending classes should override `query` or implement this method
     */
    _all(q: Query, options?: Options): AsyncIterable<Pair>;
    /**
     * Extending classes should override `queryKeys` or implement this method
     */
    _allKeys(q: KeyQuery, options?: Options): AsyncIterable<Key>;
    query(q: Query, options?: Options): AsyncIterable<Pair>;
    queryKeys(q: KeyQuery, options?: Options): AsyncIterable<Key>;
}
//# sourceMappingURL=base.d.ts.map