import { BaseDatastore } from './base.js';
import type { KeyTransform } from './index.js';
import type { Batch, Datastore, Key, KeyQuery, Options, Pair, Query } from 'interface-datastore';
import type { AwaitIterable } from 'interface-store';
/**
 * A datastore shim, that wraps around a given datastore, changing
 * the way keys look to the user, for example namespacing
 * keys, reversing them, etc.
 */
export declare class KeyTransformDatastore extends BaseDatastore {
    private readonly child;
    transform: KeyTransform;
    constructor(child: Datastore, transform: KeyTransform);
    put(key: Key, val: Uint8Array, options?: Options): Promise<void>;
    get(key: Key, options?: Options): Promise<Uint8Array>;
    has(key: Key, options?: Options): Promise<boolean>;
    delete(key: Key, options?: Options): Promise<void>;
    putMany(source: AwaitIterable<Pair>, options?: Options): AsyncIterable<Pair>;
    getMany(source: AwaitIterable<Key>, options?: Options): AsyncIterable<Uint8Array>;
    deleteMany(source: AwaitIterable<Key>, options?: Options): AsyncIterable<Key>;
    batch(): Batch;
    query(q: Query, options?: Options): AsyncIterable<Pair>;
    queryKeys(q: KeyQuery, options?: Options): AsyncIterable<Key>;
}
//# sourceMappingURL=keytransform.d.ts.map