import { BaseDatastore } from './base.js';
import { Key } from 'interface-datastore/key';
import * as Errors from './errors.js';
export class MemoryDatastore extends BaseDatastore {
    constructor() {
        super();
        this.data = new Map();
    }
    async put(key, val) {
        this.data.set(key.toString(), val);
    }
    async get(key) {
        const result = this.data.get(key.toString());
        if (result == null) {
            throw Errors.notFoundError();
        }
        return result;
    }
    async has(key) {
        return this.data.has(key.toString());
    }
    async delete(key) {
        this.data.delete(key.toString());
    }
    async *_all() {
        for (const [key, value] of this.data.entries()) {
            yield { key: new Key(key), value };
        }
    }
    async *_allKeys() {
        for (const key of this.data.keys()) {
            yield new Key(key);
        }
    }
}
//# sourceMappingURL=memory.js.map