import { BaseDatastore } from './base.js';
import type { Batch, Datastore, Key, KeyQuery, Options, Pair, Query } from 'interface-datastore';
import type { AwaitIterable } from 'interface-store';
/**
 * A datastore that can combine multiple stores. Puts and deletes
 * will write through to all datastores. Has and get will
 * try each store sequentially. Query will always try the
 * last one first.
 *
 */
export declare class TieredDatastore extends BaseDatastore {
    private readonly stores;
    constructor(stores: Datastore[]);
    put(key: Key, value: Uint8Array, options?: Options): Promise<void>;
    get(key: Key, options?: Options): Promise<Uint8Array>;
    has(key: Key, options?: Options): Promise<boolean>;
    delete(key: Key, options?: Options): Promise<void>;
    putMany(source: AwaitIterable<Pair>, options?: Options): AsyncIterable<Pair>;
    deleteMany(source: AwaitIterable<Key>, options?: Options): AsyncIterable<Key>;
    batch(): Batch;
    query(q: Query, options?: Options): AsyncIterable<Pair>;
    queryKeys(q: KeyQuery, options?: Options): AsyncIterable<Key>;
}
//# sourceMappingURL=tiered.d.ts.map